*********************************************
:mod:`mopidy.backends.local` -- Local backend
*********************************************

.. automodule:: mopidy.backends.local
    :synopsis: Backend for playing music files on local storage
    :members:
